// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.

const helpers = require('../helpers/helpers.js');

exports.command = function(element, waitTime, scrollIntoView = true) {

  if (waitTime === undefined) {
    waitTime = helpers.maxWaitTime;
  }

  this.waitForElementVisible(element);

  if (scrollIntoView) {
    this.execute(function(selector) {
      document.querySelector(selector).scrollIntoView();
    }, [element]);
  }

  this.pause(200).click(element);

  return this;
};
